@@ -1,4 +1,5 @@
 import logbook
+import attr
 
 from regipy.hive_types import SYSTEM_HIVE_TYPE
 from regipy.plugins.plugin import Plugin
@@ -16,7 +17,9 @@ class ActiveControlSetPlugin(Plugin):
 
     def run(self):
         subkey = self.registry_hive.get_key(SELECT)
-        return [x for x in subkey.iter_values(as_json=self.as_json)]
+        self.entries = [x for x in subkey.iter_values(as_json=self.as_json)]
+        if self.as_json:
+            self.entries = [attr.asdict(x) for x in self.entries]
 
 
 
